@@ -65,6 +65,8 @@ export default function GroupForm(props) {
                       aria2_options: "{}", // json decode
                       compress_size: "0",
                       decompress_size: "0",
+                      source_batch: "0",
+                      aria2_batch: "1",
                   },
               }
     );
@@ -162,7 +164,12 @@ export default function GroupForm(props) {
         ["MaxStorage", "SpeedLimit"].forEach((v) => {
             groupCopy[v] = parseInt(groupCopy[v]);
         });
-        ["compress_size", "decompress_size"].forEach((v) => {
+        [
+            "compress_size",
+            "decompress_size",
+            "source_batch",
+            "aria2_batch",
+        ].forEach((v) => {
             if (groupCopy.OptionsSerialized[v] !== undefined) {
                 groupCopy.OptionsSerialized[v] = parseInt(
                     groupCopy.OptionsSerialized[v]
@@ -300,6 +307,34 @@ export default function GroupForm(props) {
                             </FormHelperText>
                         </div>
 
+                        {group.ID !== 3 && (
+                            <div className={classes.form}>
+                                <FormControl fullWidth>
+                                    <InputLabel htmlFor="component-helper">
+                                        批量生成外链数量限制
+                                    </InputLabel>
+                                    <Input
+                                        multiline
+                                        type={"number"}
+                                        inputProps={{
+                                            min: 1,
+                                            step: 1,
+                                        }}
+                                        value={
+                                            group.OptionsSerialized.source_batch
+                                        }
+                                        onChange={handleOptionChange(
+                                            "source_batch"
+                                        )}
+                                    />
+                                    <FormHelperText id="component-helper-text">
+                                        对于支持的存储策略下的文件，允许用户单次批量获取外链的最大文件数量，填写为
+                                        0 或空表示不允许批量生成外链。
+                                    </FormHelperText>
+                                </FormControl>
+                            </div>
+                        )}
+
                         {group.ID !== 3 && (
                             <div className={classes.form}>
                                 <FormControl fullWidth>
@@ -442,6 +477,30 @@ export default function GroupForm(props) {
                                     </FormHelperText>
                                 </FormControl>
                             </div>
+                            <div className={classes.form}>
+                                <FormControl fullWidth>
+                                    <InputLabel htmlFor="component-helper">
+                                        Aria2 批量下载最大数量
+                                    </InputLabel>
+                                    <Input
+                                        multiline
+                                        type={"number"}
+                                        inputProps={{
+                                            min: 1,
+                                            step: 1,
+                                        }}
+                                        value={
+                                            group.OptionsSerialized.aria2_batch
+                                        }
+                                        onChange={handleOptionChange(
+                                            "aria2_batch"
+                                        )}
+                                    />
+                                    <FormHelperText id="component-helper-text">
+                                        允许用户单次批量创建的离线下载链接的最大数量
+                                    </FormHelperText>
+                                </FormControl>
+                            </div>
                         </Collapse>
 
                         <div className={classes.form}>
