@@ -44,7 +44,7 @@ import {
 } from "recharts";
 import { ResponsiveContainer } from "recharts/lib/component/ResponsiveContainer";
 import TimeAgo from "timeago-react";
-import { toggleSnackbar } from "../../actions";
+import { toggleSnackbar } from "../../redux/explorer";
 import API from "../../middleware/Api";
 import pathHelper from "../../utils/page";
 
@@ -182,7 +182,12 @@ export default function Index() {
                 setNewsUsers(res);
             })
             .catch((error) => {
-                ToggleSnackbar("top", "right", error.message, "error");
+                ToggleSnackbar(
+                    "top",
+                    "right",
+                    "Cloudreve 公告加载失败",
+                    "warning"
+                );
             });
     }, []);
 
