@@ -21,7 +21,7 @@ import { Block, Delete, Edit, FilterList } from "@material-ui/icons";
 import React, { useCallback, useEffect, useState } from "react";
 import { useDispatch } from "react-redux";
 import { useHistory } from "react-router";
-import { toggleSnackbar } from "../../../actions";
+import { toggleSnackbar } from "../../../redux/explorer";
 import API from "../../../middleware/Api";
 import { sizeToString } from "../../../utils";
 import UserFilter from "../Dialogs/UserFilter";
