@@ -45,7 +45,7 @@ const mapStateToProps = (state) => {
         refresh: state.navigator.refresh,
         drawerDesktopOpen: state.viewUpdate.open,
         viewMethod: state.viewUpdate.explorerViewMethod,
-        keywords: state.explorer.keywords,
+        search: state.explorer.search,
         sortMethod: state.viewUpdate.sortMethod,
     };
 };
@@ -101,8 +101,6 @@ const styles = (theme) => ({
         [theme.breakpoints.down("xs")]: {
             display: "none",
         },
-        height: "49px",
-        overflow: "hidden",
         backgroundColor: theme.palette.background.paper,
     },
     navigatorContainer: {
@@ -132,7 +130,7 @@ const styles = (theme) => ({
 });
 
 class NavigatorComponent extends Component {
-    keywords = "";
+    search = undefined;
     currentID = 0;
 
     state = {
@@ -178,12 +176,17 @@ class NavigatorComponent extends Component {
                     : this.props.path.substr(1).split("/"),
         });
         const newPath = path !== null ? path : this.props.path;
-        list(newPath, this.props.share, this.keywords)
+        list(
+            newPath,
+            this.props.share,
+            this.search ? this.search.keywords : "",
+            this.search ? this.search.searchPath : ""
+        )
             .then((response) => {
                 this.currentID = response.data.parent;
                 this.props.updateFileList(response.data.objects);
                 this.props.setNavigatorLoadingStatus(false);
-                if (this.keywords === "") {
+                if (!this.search) {
                     setGetParameter("path", encodeURIComponent(newPath));
                 }
                 if (response.data.policy) {
@@ -210,8 +213,8 @@ class NavigatorComponent extends Component {
     };
 
     UNSAFE_componentWillReceiveProps = (nextProps) => {
-        if (this.props.keywords !== nextProps.keywords) {
-            this.keywords = nextProps.keywords;
+        if (this.props.search !== nextProps.search) {
+            this.search = nextProps.search;
         }
         if (this.props.path !== nextProps.path) {
             this.renderPath(nextProps.path);
@@ -339,7 +342,7 @@ class NavigatorComponent extends Component {
                     </ListItemIcon>
                     刷新
                 </MenuItem>
-                {this.props.keywords === "" && isHomePage && (
+                {!this.props.search && isHomePage && (
                     <div>
                         <Divider />
                         <MenuItem onClick={() => this.performAction("share")}>
@@ -477,7 +480,7 @@ class NavigatorComponent extends Component {
                             ))}
                     </div>
                     <div className={classes.optionContainer}>
-                        <SubActions isSmall share={this.props.share} />
+                        <SubActions isSmall />
                     </div>
                 </div>
                 <Divider />
